LowPowerOutputOpenDrain

Struct LowPowerOutputOpenDrain 

pub struct LowPowerOutputOpenDrain<'d, const PIN: u8> { /* private fields */ }
Available on crate feature unstable only.
A GPIO open-drain output pin configured for low-power operation.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl<'d, const PIN: u8> LowPowerOutputOpenDrain<'d, PIN>

pub fn new<P>(pin: P) -> Self
where P: LowPowerPin<PIN> + InputPin + OutputPin + 'd,

Creates a new open-drain output pin for use by the low-power core.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn pullup_enable(&self, enable: bool)

Enables or disables the internal pull-up resistor.

pub fn pulldown_enable(&self, enable: bool)

Enables or disables the internal pull-down resistor.