pub struct LowPowerOutput<'d, const PIN: u8> { /* private fields */ }Available on crate feature
unstable only.Expand description
A GPIO output pin configured for low-power operation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'d, const PIN: u8> LowPowerOutput<'d, PIN>
impl<'d, const PIN: u8> LowPowerOutput<'d, PIN>
Sourcepub fn new<P>(pin: P) -> Selfwhere
P: LowPowerPin<PIN> + OutputPin + 'd,
pub fn new<P>(pin: P) -> Selfwhere
P: LowPowerPin<PIN> + OutputPin + 'd,
Creates a new output pin for use by the low-power core.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.