pub struct LowPowerOutputOpenDrain<'d, const PIN: u8> { /* private fields */ }Available on crate feature
unstable only.Expand description
A GPIO open-drain output pin configured for low-power operation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'d, const PIN: u8> LowPowerOutputOpenDrain<'d, PIN>
impl<'d, const PIN: u8> LowPowerOutputOpenDrain<'d, PIN>
Sourcepub fn new<P>(pin: P) -> Self
pub fn new<P>(pin: P) -> Self
Creates a new open-drain output pin for use by the low-power core.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn pullup_enable(&self, enable: bool)
pub fn pullup_enable(&self, enable: bool)
Enables or disables the internal pull-up resistor.
Sourcepub fn pulldown_enable(&self, enable: bool)
pub fn pulldown_enable(&self, enable: bool)
Enables or disables the internal pull-down resistor.